# -*- coding: utf-8 -*-

import os
import datetime
import json
import csv

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.shopify.order_util import OrderUtil
from em_tasks.store.models import *


@click.command('Import Disputes')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
def import_disputes(store_code):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  credential = json.loads(store.api_credential)
  order_util = OrderUtil(credential['name'], credential['token'], credential.get('release', None))

  dispute = Dispute.select().where(Dispute.finalized_on.is_null(True)).order_by(Dispute.s_id.asc()).limit(1).execute()
  if dispute:
    payload = {'since_id': dispute.s_id}
  else:
    payload= None

  order_util.import_disputes(payload)


if __name__ == "__main__":
  import_disputes()
