# -*- coding: utf-8 -*-

import os

import click

from dropshipping.utils.utils import is_asin_valid

from em_tasks.spapi import Spapi
from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.tasks.spapi_fetch_products_task import SpapiFetchProductsTask
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_offer_service, get_product_service


@click.command('Fetch Amazon products offers and information via SPAPI')
@click.option('-m', '--marketplace', type=str, default='us')
@click.option('-c', '--condition', type=str, default='new')
@click.option('-b', '--batch_size', type=int, default=20)
@click.argument('products_path')
def fetch_products(products_path, marketplace='us', condition='new', batch_size=20):
  init_db()

  if not products_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  offer_service = get_offer_service()
  product_service = get_product_service()

  cfg = get_config()
  spapi_cfg = cfg['spapi']
  credentials = {
    'refresh_token': spapi_cfg['lwa_refresh_token'],
    'lwa_app_id': spapi_cfg['lwa_client_id'],
    'lwa_client_secret': spapi_cfg['lwa_client_secret'],
    'aws_access_key': spapi_cfg['aws_access_key'],
    'aws_secret_key': spapi_cfg['aws_secret_key']
  }
  spapi = Spapi(credentials)

  asins_buf = []
  buf_size = 100
  with open(products_path, encoding='utf-8', errors='ignore') as fh:
    for line in fh:
      s = line.strip()
      if not is_asin_valid(s):
        continue

      asins_buf.append(s)
      if len(asins_buf) < buf_size:
        continue

      task = SpapiFetchProductsTask(
        spapi, offer_service, product_service, marketplace, asins_buf, condition, True, batch_size)
      task.run()

      asins_buf = []

    if asins_buf:
      task = SpapiFetchProductsTask(
        spapi, offer_service, product_service, marketplace, asins_buf, condition, True, batch_size)
      task.run()

      asins_buf = []


if __name__ == "__main__":
  fetch_products()
