# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.order_util import OrderUtil
from em_tasks.store.models import *


@click.command('Import Spree Orders')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=3, help='Sync how many days order, default is 3.')
def import_orders(store_code, days=3):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  credential = json.loads(store.api_credential)
  order_util = OrderUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))

  today = datetime.datetime.utcnow()
  from_date = today - datetime.timedelta(days=days)
  from_date_s = from_date.date().isoformat()
  order_util.import_orders({'q[completed_at_gt]': from_date_s})
  order_util.import_orders({'q[updated_at_gt]': from_date_s})


if __name__ == "__main__":
  import_orders()
