# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.order_util import OrderUtil
from em_tasks.store.models import *


@click.command('Upload Spree Orders tracking')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=14, help='Upload how many days order trackings, default is 14.')
def upload_trackings(store_code, days=14):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  credential = json.loads(store.api_credential)
  order_util = OrderUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
  # order_util = OrderUtil('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))
  order_util.upload_trackings(days)


if __name__ == "__main__":
  upload_trackings()
